==> qlcplus_4.13.1.orig.tar.xz: qlcplus-QLC-_4.13.1/plugins/osc/OSC_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>OSC Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universen konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Eingangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Ausgangsadresse</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Ausgangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="90"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Sekunden um auf die Bereitschaft eines Interfaces zu warten</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="122"/>
        <source>Channel number calculator</source>
        <translation>Kanalnummer-Rechner</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="130"/>
        <source>OSC path</source>
        <translation>OSC-Pfad</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="140"/>
        <source>Channel number</source>
        <translation>Kanal-Nummer</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="88"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="94"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="176"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="96"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Dieses Plugin bietet Eingabunterstützung für Geräte mit dem OSC-Protokoll.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <location filename="oscplugin.cpp" line="280"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="150"/>
        <location filename="oscplugin.cpp" line="283"/>
        <source>Status: Open</source>
        <translation>Status: Geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="152"/>
        <source>Packets sent: </source>
        <translation>Pakete gesendet: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="285"/>
        <source>Packets received: </source>
        <translation>Pakete empfangen: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="143"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
</context>
</TS>

==> qlcplus_4.14.1.orig.tar.xz: qlcplus-QLC-_4.14.1/plugins/osc/OSC_de_DE.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ConfigureOSC</name>
    <message>
        <location filename="configureosc.ui" line="33"/>
        <source>OSC Plugin Configuration</source>
        <oldsource>Configure OSC Plugin</oldsource>
        <translation>OSC-Plugin konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="47"/>
        <source>Universes Configuration</source>
        <translation>Universen konfigurieren</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="60"/>
        <source>Interface</source>
        <translation>Interface</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="65"/>
        <source>Universe</source>
        <translation>Universum</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="70"/>
        <source>Input Port</source>
        <translation>Eingangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="75"/>
        <source>Output Address</source>
        <translation>Ausgangsadresse</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="80"/>
        <source>Output Port</source>
        <translation>Ausgangsport</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="90"/>
        <source>Seconds to wait for an interface to be ready</source>
        <translation>Sekunden, um auf die Bereitschaft eines Interfaces zu warten</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="122"/>
        <source>Channel number calculator</source>
        <translation>Kanalnummer-Rechner</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="130"/>
        <source>OSC path</source>
        <translation>OSC-Pfad</translation>
    </message>
    <message>
        <location filename="configureosc.ui" line="140"/>
        <source>Channel number</source>
        <translation>Kanal-Nummer</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="96"/>
        <source>Inputs</source>
        <translation>Eingänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="102"/>
        <source>Outputs</source>
        <translation>Ausgänge</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="184"/>
        <source>Invalid IP</source>
        <translation>Ungültige IP</translation>
    </message>
    <message>
        <location filename="configureosc.cpp" line="184"/>
        <source>%1 is not a valid IP.
Please fix it before confirming.</source>
        <translation>%1 ist keine gültige IP.
Bitte vor Bestätigung korrigieren.</translation>
    </message>
</context>
<context>
    <name>OSCPlugin</name>
    <message>
        <location filename="oscplugin.cpp" line="96"/>
        <source>This plugin provides input for devices supporting the OSC transmission protocol.</source>
        <translation>Dieses Plugin bietet Eingabeunterstützung für Geräte mit dem OSC-Protokoll.</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="147"/>
        <location filename="oscplugin.cpp" line="280"/>
        <source>Status: Not open</source>
        <translation>Status: Nicht geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="150"/>
        <location filename="oscplugin.cpp" line="283"/>
        <source>Status: Open</source>
        <translation>Status: Geöffnet</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="152"/>
        <source>Packets sent: </source>
        <translation>Pakete gesendet: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="285"/>
        <source>Packets received: </source>
        <translation>Pakete empfangen: </translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="143"/>
        <source>Output</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="oscplugin.cpp" line="276"/>
        <source>Input</source>
        <translation>Eingang</translation>
    </message>
</context>
</TS>
